import * as pulumi from "@pulumi/pulumi";
/**
 * The ``AWS::ApiGateway::DocumentationPart`` resource creates a documentation part for an API. For more information, see [Representation of API Documentation in API Gateway](https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-documenting-api-content-representation.html) in the *API Gateway Developer Guide*.
 */
export declare function getDocumentationPart(args: GetDocumentationPartArgs, opts?: pulumi.InvokeOptions): Promise<GetDocumentationPartResult>;
export interface GetDocumentationPartArgs {
    /**
     * The ID for the documentation part.
     */
    documentationPartId: string;
    /**
     * The string identifier of the associated RestApi.
     */
    restApiId: string;
}
export interface GetDocumentationPartResult {
    /**
     * The ID for the documentation part.
     */
    readonly documentationPartId?: string;
    /**
     * The new documentation content map of the targeted API entity. Enclosed key-value pairs are API-specific, but only OpenAPI-compliant key-value pairs can be exported and, hence, published.
     */
    readonly properties?: string;
}
/**
 * The ``AWS::ApiGateway::DocumentationPart`` resource creates a documentation part for an API. For more information, see [Representation of API Documentation in API Gateway](https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-documenting-api-content-representation.html) in the *API Gateway Developer Guide*.
 */
export declare function getDocumentationPartOutput(args: GetDocumentationPartOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDocumentationPartResult>;
export interface GetDocumentationPartOutputArgs {
    /**
     * The ID for the documentation part.
     */
    documentationPartId: pulumi.Input<string>;
    /**
     * The string identifier of the associated RestApi.
     */
    restApiId: pulumi.Input<string>;
}
