import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The ``AWS::ApiGateway::Stage`` resource creates a stage for a deployment.
 */
export declare function getStage(args: GetStageArgs, opts?: pulumi.InvokeOptions): Promise<GetStageResult>;
export interface GetStageArgs {
    /**
     * The string identifier of the associated RestApi.
     */
    restApiId: string;
    /**
     * The name of the stage is the first path segment in the Uniform Resource Identifier (URI) of a call to API Gateway. Stage names can only contain alphanumeric characters, hyphens, and underscores. Maximum length is 128 characters.
     */
    stageName: string;
}
export interface GetStageResult {
    /**
     * Access log settings, including the access log format and access log destination ARN.
     */
    readonly accessLogSetting?: outputs.apigateway.StageAccessLogSetting;
    /**
     * Specifies whether a cache cluster is enabled for the stage. To activate a method-level cache, set `CachingEnabled` to `true` for a method.
     */
    readonly cacheClusterEnabled?: boolean;
    /**
     * The stage's cache capacity in GB. For more information about choosing a cache size, see [Enabling API caching to enhance responsiveness](https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-caching.html) .
     */
    readonly cacheClusterSize?: string;
    /**
     * Settings for the canary deployment in this stage.
     */
    readonly canarySetting?: outputs.apigateway.StageCanarySetting;
    /**
     * The identifier of a client certificate for an API stage.
     */
    readonly clientCertificateId?: string;
    /**
     * The identifier of the Deployment that the stage points to.
     */
    readonly deploymentId?: string;
    /**
     * The stage's description.
     */
    readonly description?: string;
    /**
     * The version of the associated API documentation.
     */
    readonly documentationVersion?: string;
    /**
     * A map that defines the method settings for a Stage resource. Keys (designated as `/{method_setting_key` below) are method paths defined as `{resource_path}/{http_method}` for an individual method override, or `/\*&#47;\*` for overriding all methods in the stage.
     */
    readonly methodSettings?: outputs.apigateway.StageMethodSetting[];
    /**
     * The collection of tags. Each tag element is associated with a given resource.
     */
    readonly tags?: outputs.Tag[];
    /**
     * Specifies whether active tracing with X-ray is enabled for the Stage.
     */
    readonly tracingEnabled?: boolean;
    /**
     * A map (string-to-string map) that defines the stage variables, where the variable name is the key and the variable value is the value. Variable names are limited to alphanumeric characters. Values must match the following regular expression: ``[A-Za-z0-9-._~:/?#&=,]+``.
     */
    readonly variables?: {
        [key: string]: string;
    };
}
/**
 * The ``AWS::ApiGateway::Stage`` resource creates a stage for a deployment.
 */
export declare function getStageOutput(args: GetStageOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetStageResult>;
export interface GetStageOutputArgs {
    /**
     * The string identifier of the associated RestApi.
     */
    restApiId: pulumi.Input<string>;
    /**
     * The name of the stage is the first path segment in the Uniform Resource Identifier (URI) of a call to API Gateway. Stage names can only contain alphanumeric characters, hyphens, and underscores. Maximum length is 128 characters.
     */
    stageName: pulumi.Input<string>;
}
