import * as pulumi from "@pulumi/pulumi";
/**
 * The ``AWS::ApiGatewayV2::Deployment`` resource creates a deployment for an API.
 */
export declare class Deployment extends pulumi.CustomResource {
    /**
     * Get an existing Deployment resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Deployment;
    /**
     * Returns true if the given object is an instance of Deployment.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Deployment;
    /**
     * The API identifier.
     */
    readonly apiId: pulumi.Output<string>;
    /**
     * The deployment ID.
     */
    readonly deploymentId: pulumi.Output<string>;
    /**
     * The description for the deployment resource.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The name of an existing stage to associate with the deployment.
     */
    readonly stageName: pulumi.Output<string | undefined>;
    /**
     * Create a Deployment resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DeploymentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Deployment resource.
 */
export interface DeploymentArgs {
    /**
     * The API identifier.
     */
    apiId: pulumi.Input<string>;
    /**
     * The description for the deployment resource.
     */
    description?: pulumi.Input<string>;
    /**
     * The name of an existing stage to associate with the deployment.
     */
    stageName?: pulumi.Input<string>;
}
