import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::AppStream::Application
 */
export declare class Application extends pulumi.CustomResource {
    /**
     * Get an existing Application resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Application;
    /**
     * Returns true if the given object is an instance of Application.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Application;
    /**
     * The app block ARN with which the application should be associated.
     */
    readonly appBlockArn: pulumi.Output<string>;
    /**
     * The ARN of the application.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * A list of attributes to delete from an application.
     */
    readonly attributesToDelete: pulumi.Output<string[] | undefined>;
    /**
     * The time when the application was created.
     */
    readonly createdTime: pulumi.Output<string>;
    /**
     * The description of the application.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The display name of the application. This name is visible to users in the application catalog.
     */
    readonly displayName: pulumi.Output<string | undefined>;
    /**
     * The icon S3 location of the application.
     */
    readonly iconS3Location: pulumi.Output<outputs.appstream.ApplicationS3Location>;
    /**
     * The instance families the application supports.
     *
     * *Allowed Values* : `GENERAL_PURPOSE` | `GRAPHICS_G4`
     */
    readonly instanceFamilies: pulumi.Output<string[]>;
    /**
     * The launch parameters of the application.
     */
    readonly launchParameters: pulumi.Output<string | undefined>;
    /**
     * The launch path of the application.
     */
    readonly launchPath: pulumi.Output<string>;
    /**
     * The name of the application. This name is visible to users when a name is not specified in the DisplayName property.
     *
     * *Pattern* : `^[a-zA-Z0-9][a-zA-Z0-9_.-]{0,100}$`
     */
    readonly name: pulumi.Output<string>;
    /**
     * The platforms the application supports.
     *
     * *Allowed Values* : `WINDOWS_SERVER_2019` | `AMAZON_LINUX2`
     */
    readonly platforms: pulumi.Output<string[]>;
    /**
     * The tags of the application.
     */
    readonly tags: pulumi.Output<(outputs.appstream.ApplicationTag0Properties | outputs.appstream.ApplicationTag1Properties)[] | undefined>;
    /**
     * The working directory of the application.
     */
    readonly workingDirectory: pulumi.Output<string | undefined>;
    /**
     * Create a Application resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ApplicationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Application resource.
 */
export interface ApplicationArgs {
    /**
     * The app block ARN with which the application should be associated.
     */
    appBlockArn: pulumi.Input<string>;
    /**
     * A list of attributes to delete from an application.
     */
    attributesToDelete?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The description of the application.
     */
    description?: pulumi.Input<string>;
    /**
     * The display name of the application. This name is visible to users in the application catalog.
     */
    displayName?: pulumi.Input<string>;
    /**
     * The icon S3 location of the application.
     */
    iconS3Location: pulumi.Input<inputs.appstream.ApplicationS3LocationArgs>;
    /**
     * The instance families the application supports.
     *
     * *Allowed Values* : `GENERAL_PURPOSE` | `GRAPHICS_G4`
     */
    instanceFamilies: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The launch parameters of the application.
     */
    launchParameters?: pulumi.Input<string>;
    /**
     * The launch path of the application.
     */
    launchPath: pulumi.Input<string>;
    /**
     * The name of the application. This name is visible to users when a name is not specified in the DisplayName property.
     *
     * *Pattern* : `^[a-zA-Z0-9][a-zA-Z0-9_.-]{0,100}$`
     */
    name?: pulumi.Input<string>;
    /**
     * The platforms the application supports.
     *
     * *Allowed Values* : `WINDOWS_SERVER_2019` | `AMAZON_LINUX2`
     */
    platforms: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The tags of the application.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.appstream.ApplicationTag0PropertiesArgs | inputs.appstream.ApplicationTag1PropertiesArgs>[]>;
    /**
     * The working directory of the application.
     */
    workingDirectory?: pulumi.Input<string>;
}
