import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::AppStream::DirectoryConfig
 */
export declare function getDirectoryConfig(args: GetDirectoryConfigArgs, opts?: pulumi.InvokeOptions): Promise<GetDirectoryConfigResult>;
export interface GetDirectoryConfigArgs {
    /**
     * The fully qualified name of the directory (for example, corp.example.com).
     */
    directoryName: string;
}
export interface GetDirectoryConfigResult {
    /**
     * The certificate-based authentication properties used to authenticate SAML 2.0 Identity Provider (IdP) user identities to Active Directory domain-joined streaming instances.
     */
    readonly certificateBasedAuthProperties?: outputs.appstream.DirectoryConfigCertificateBasedAuthProperties;
    /**
     * The distinguished names of the organizational units for computer accounts.
     */
    readonly organizationalUnitDistinguishedNames?: string[];
    /**
     * The credentials for the service account used by the streaming instance to connect to the directory. Do not use this parameter directly. Use `ServiceAccountCredentials` as an input parameter with `noEcho` as shown in the [Parameters](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/parameters-section-structure.html) . For best practices information, see [Do Not Embed Credentials in Your Templates](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/best-practices.html#creds) .
     */
    readonly serviceAccountCredentials?: outputs.appstream.DirectoryConfigServiceAccountCredentials;
}
/**
 * Resource Type definition for AWS::AppStream::DirectoryConfig
 */
export declare function getDirectoryConfigOutput(args: GetDirectoryConfigOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDirectoryConfigResult>;
export interface GetDirectoryConfigOutputArgs {
    /**
     * The fully qualified name of the directory (for example, corp.example.com).
     */
    directoryName: pulumi.Input<string>;
}
