import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Definition of AWS::B2BI::Capability Resource Type
 */
export declare function getCapability(args: GetCapabilityArgs, opts?: pulumi.InvokeOptions): Promise<GetCapabilityResult>;
export interface GetCapabilityArgs {
    /**
     * Returns a system-assigned unique identifier for the capability.
     */
    capabilityId: string;
}
export interface GetCapabilityResult {
    /**
     * Returns an Amazon Resource Name (ARN) for a specific AWS resource, such as a capability, partnership, profile, or transformer.
     */
    readonly capabilityArn?: string;
    /**
     * Returns a system-assigned unique identifier for the capability.
     */
    readonly capabilityId?: string;
    /**
     * Specifies a structure that contains the details for a capability.
     */
    readonly configuration?: outputs.b2bi.CapabilityConfigurationProperties;
    /**
     * Returns a timestamp for creation date and time of the capability.
     */
    readonly createdAt?: string;
    /**
     * Specifies one or more locations in Amazon S3, each specifying an EDI document that can be used with this capability. Each item contains the name of the bucket and the key, to identify the document's location.
     */
    readonly instructionsDocuments?: outputs.b2bi.CapabilityS3Location[];
    /**
     * Returns a timestamp that identifies the most recent date and time that the capability was modified.
     */
    readonly modifiedAt?: string;
    /**
     * The display name of the capability.
     */
    readonly name?: string;
    /**
     * Specifies the key-value pairs assigned to ARNs that you can use to group and search for resources by type. You can attach this metadata to resources (capabilities, partnerships, and so on) for any purpose.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Definition of AWS::B2BI::Capability Resource Type
 */
export declare function getCapabilityOutput(args: GetCapabilityOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCapabilityResult>;
export interface GetCapabilityOutputArgs {
    /**
     * Returns a system-assigned unique identifier for the capability.
     */
    capabilityId: pulumi.Input<string>;
}
