import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Definition of AWS::Backup::RestoreTestingPlan Resource Type
 */
export declare function getRestoreTestingPlan(args: GetRestoreTestingPlanArgs, opts?: pulumi.InvokeOptions): Promise<GetRestoreTestingPlanResult>;
export interface GetRestoreTestingPlanArgs {
    /**
     * The RestoreTestingPlanName is a unique string that is the name of the restore testing plan. This cannot be changed after creation, and it must consist of only alphanumeric characters and underscores.
     */
    restoreTestingPlanName: string;
}
export interface GetRestoreTestingPlanResult {
    /**
     * The specified criteria to assign a set of resources, such as recovery point types or backup vaults.
     */
    readonly recoveryPointSelection?: outputs.backup.RestoreTestingPlanRestoreTestingRecoveryPointSelection;
    /**
     * An Amazon Resource Name (ARN) that uniquely identifies a restore testing plan.
     */
    readonly restoreTestingPlanArn?: string;
    /**
     * A CRON expression in specified timezone when a restore testing plan is executed. When no CRON expression is provided, AWS Backup will use the default expression `cron(0 5 ? * * *)` .
     */
    readonly scheduleExpression?: string;
    /**
     * Optional. This is the timezone in which the schedule expression is set. By default, ScheduleExpressions are in UTC. You can modify this to a specified timezone.
     */
    readonly scheduleExpressionTimezone?: string;
    /**
     * Defaults to 24 hours.
     *
     * A value in hours after a restore test is scheduled before a job will be canceled if it doesn't start successfully. This value is optional. If this value is included, this parameter has a maximum value of 168 hours (one week).
     */
    readonly startWindowHours?: number;
    /**
     * Optional tags to include. A tag is a key-value pair you can use to manage, filter, and search for your resources. Allowed characters include UTF-8 letters,numbers, spaces, and the following characters: `+ - = . _ : /.`
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Definition of AWS::Backup::RestoreTestingPlan Resource Type
 */
export declare function getRestoreTestingPlanOutput(args: GetRestoreTestingPlanOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRestoreTestingPlanResult>;
export interface GetRestoreTestingPlanOutputArgs {
    /**
     * The RestoreTestingPlanName is a unique string that is the name of the restore testing plan. This cannot be changed after creation, and it must consist of only alphanumeric characters and underscores.
     */
    restoreTestingPlanName: pulumi.Input<string>;
}
