import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::Bedrock::FlowAlias Resource Type
 */
export declare class FlowAlias extends pulumi.CustomResource {
    /**
     * Get an existing FlowAlias resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): FlowAlias;
    /**
     * Returns true if the given object is an instance of FlowAlias.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is FlowAlias;
    /**
     * Arn of the Flow Alias
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Id for a Flow Alias generated at the server side.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * Time Stamp.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * Description of the Resource.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Arn representation of the Flow
     */
    readonly flowArn: pulumi.Output<string>;
    /**
     * Identifier for a flow resource.
     */
    readonly flowId: pulumi.Output<string>;
    /**
     * Name for a resource.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Routing configuration for a Flow alias.
     */
    readonly routingConfiguration: pulumi.Output<outputs.bedrock.FlowAliasRoutingConfigurationListItem[]>;
    /**
     * Metadata that you can assign to a resource as key-value pairs. For more information, see the following resources:
     *
     * - [Tag naming limits and requirements](https://docs.aws.amazon.com/tag-editor/latest/userguide/tagging.html#tag-conventions)
     * - [Tagging best practices](https://docs.aws.amazon.com/tag-editor/latest/userguide/tagging.html#tag-best-practices)
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Time Stamp.
     */
    readonly updatedAt: pulumi.Output<string>;
    /**
     * Create a FlowAlias resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: FlowAliasArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a FlowAlias resource.
 */
export interface FlowAliasArgs {
    /**
     * Description of the Resource.
     */
    description?: pulumi.Input<string>;
    /**
     * Arn representation of the Flow
     */
    flowArn: pulumi.Input<string>;
    /**
     * Name for a resource.
     */
    name?: pulumi.Input<string>;
    /**
     * Routing configuration for a Flow alias.
     */
    routingConfiguration: pulumi.Input<pulumi.Input<inputs.bedrock.FlowAliasRoutingConfigurationListItemArgs>[]>;
    /**
     * Metadata that you can assign to a resource as key-value pairs. For more information, see the following resources:
     *
     * - [Tag naming limits and requirements](https://docs.aws.amazon.com/tag-editor/latest/userguide/tagging.html#tag-conventions)
     * - [Tagging best practices](https://docs.aws.amazon.com/tag-editor/latest/userguide/tagging.html#tag-best-practices)
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
