import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::CE::CostCategory. Cost Category enables you to map your cost and usage into meaningful categories. You can use Cost Category to organize your costs using a rule-based engine.
 */
export declare function getCostCategory(args: GetCostCategoryArgs, opts?: pulumi.InvokeOptions): Promise<GetCostCategoryResult>;
export interface GetCostCategoryArgs {
    /**
     * Cost category ARN
     */
    arn: string;
}
export interface GetCostCategoryResult {
    /**
     * Cost category ARN
     */
    readonly arn?: string;
    /**
     * The default value for the cost category
     */
    readonly defaultValue?: string;
    /**
     * The Cost Category's effective start date.
     */
    readonly effectiveStart?: string;
    /**
     * The rule schema version in this particular Cost Category.
     */
    readonly ruleVersion?: enums.ce.CostCategoryRuleVersion;
    /**
     * JSON array format of Expression in Billing and Cost Management API
     */
    readonly rules?: string;
    /**
     * Json array format of CostCategorySplitChargeRule in Billing and Cost Management API
     */
    readonly splitChargeRules?: string;
    /**
     * Tags to assign to the cost category.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for AWS::CE::CostCategory. Cost Category enables you to map your cost and usage into meaningful categories. You can use Cost Category to organize your costs using a rule-based engine.
 */
export declare function getCostCategoryOutput(args: GetCostCategoryOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCostCategoryResult>;
export interface GetCostCategoryOutputArgs {
    /**
     * Cost category ARN
     */
    arn: pulumi.Input<string>;
}
