import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::CloudFront::ConnectionGroup
 */
export declare class ConnectionGroup extends pulumi.CustomResource {
    /**
     * Get an existing ConnectionGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ConnectionGroup;
    /**
     * Returns true if the given object is an instance of ConnectionGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ConnectionGroup;
    /**
     * The ID of the Anycast static IP list.
     */
    readonly anycastIpListId: pulumi.Output<string | undefined>;
    readonly arn: pulumi.Output<string>;
    readonly awsId: pulumi.Output<string>;
    readonly createdTime: pulumi.Output<string>;
    /**
     * A complex type that contains `Tag` key and `Tag` value.
     */
    readonly eTag: pulumi.Output<string>;
    readonly enabled: pulumi.Output<boolean | undefined>;
    readonly ipv6Enabled: pulumi.Output<boolean | undefined>;
    readonly isDefault: pulumi.Output<boolean>;
    readonly lastModifiedTime: pulumi.Output<string>;
    readonly name: pulumi.Output<string>;
    /**
     * Contains information about the Amazon Kinesis data stream where you are sending real-time log data in a real-time log configuration.
     */
    readonly routingEndpoint: pulumi.Output<string>;
    readonly status: pulumi.Output<string>;
    /**
     * A complex type that contains zero or more `Tag` elements.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a ConnectionGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ConnectionGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ConnectionGroup resource.
 */
export interface ConnectionGroupArgs {
    /**
     * The ID of the Anycast static IP list.
     */
    anycastIpListId?: pulumi.Input<string>;
    enabled?: pulumi.Input<boolean>;
    ipv6Enabled?: pulumi.Input<boolean>;
    name?: pulumi.Input<string>;
    /**
     * A complex type that contains zero or more `Tag` elements.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
