import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::CloudFront::DistributionTenant
 */
export declare class DistributionTenant extends pulumi.CustomResource {
    /**
     * Get an existing DistributionTenant resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DistributionTenant;
    /**
     * Returns true if the given object is an instance of DistributionTenant.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DistributionTenant;
    readonly arn: pulumi.Output<string>;
    readonly awsId: pulumi.Output<string>;
    readonly connectionGroupId: pulumi.Output<string | undefined>;
    readonly createdTime: pulumi.Output<string>;
    readonly customizations: pulumi.Output<outputs.cloudfront.DistributionTenantCustomizations | undefined>;
    /**
     * The distribution's identifier. For example: `E1U5RQF7T870K0` .
     */
    readonly distributionId: pulumi.Output<string>;
    readonly domainResults: pulumi.Output<outputs.cloudfront.DistributionTenantDomainResult[]>;
    readonly domains: pulumi.Output<string[]>;
    /**
     * A complex type that contains `Tag` key and `Tag` value.
     */
    readonly eTag: pulumi.Output<string>;
    readonly enabled: pulumi.Output<boolean | undefined>;
    readonly lastModifiedTime: pulumi.Output<string>;
    readonly managedCertificateRequest: pulumi.Output<outputs.cloudfront.DistributionTenantManagedCertificateRequest | undefined>;
    readonly name: pulumi.Output<string>;
    readonly parameters: pulumi.Output<outputs.cloudfront.DistributionTenantParameter[] | undefined>;
    readonly status: pulumi.Output<string>;
    /**
     * A complex type that contains zero or more `Tag` elements.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a DistributionTenant resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DistributionTenantArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DistributionTenant resource.
 */
export interface DistributionTenantArgs {
    connectionGroupId?: pulumi.Input<string>;
    customizations?: pulumi.Input<inputs.cloudfront.DistributionTenantCustomizationsArgs>;
    /**
     * The distribution's identifier. For example: `E1U5RQF7T870K0` .
     */
    distributionId: pulumi.Input<string>;
    domains: pulumi.Input<pulumi.Input<string>[]>;
    enabled?: pulumi.Input<boolean>;
    managedCertificateRequest?: pulumi.Input<inputs.cloudfront.DistributionTenantManagedCertificateRequestArgs>;
    name?: pulumi.Input<string>;
    parameters?: pulumi.Input<pulumi.Input<inputs.cloudfront.DistributionTenantParameterArgs>[]>;
    /**
     * A complex type that contains zero or more `Tag` elements.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
