import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::DataSync::Agent.
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const agent = new aws_native.datasync.Agent("agent", {
 *     activationKey: "AAAAA-7AAAA-GG7MC-3I9R3-27COD",
 *     agentName: "MyAgent",
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const agent = new aws_native.datasync.Agent("agent", {
 *     activationKey: "AAAAA-7AAAA-GG7MC-3I9R3-27COD",
 *     agentName: "MyAgent",
 * });
 *
 * ```
 */
export declare class Agent extends pulumi.CustomResource {
    /**
     * Get an existing Agent resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Agent;
    /**
     * Returns true if the given object is an instance of Agent.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Agent;
    /**
     * Activation key of the Agent.
     */
    readonly activationKey: pulumi.Output<string | undefined>;
    /**
     * The DataSync Agent ARN.
     */
    readonly agentArn: pulumi.Output<string>;
    /**
     * The name configured for the agent. Text reference used to identify the agent in the console.
     */
    readonly agentName: pulumi.Output<string | undefined>;
    /**
     * The service endpoints that the agent will connect to.
     */
    readonly endpointType: pulumi.Output<enums.datasync.AgentEndpointType>;
    /**
     * The ARNs of the security group used to protect your data transfer task subnets.
     */
    readonly securityGroupArns: pulumi.Output<string[] | undefined>;
    /**
     * The ARNs of the subnets in which DataSync will create elastic network interfaces for each data transfer task.
     */
    readonly subnetArns: pulumi.Output<string[] | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The ID of the VPC endpoint that the agent has access to.
     */
    readonly vpcEndpointId: pulumi.Output<string | undefined>;
    /**
     * Create a Agent resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: AgentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Agent resource.
 */
export interface AgentArgs {
    /**
     * Activation key of the Agent.
     */
    activationKey?: pulumi.Input<string>;
    /**
     * The name configured for the agent. Text reference used to identify the agent in the console.
     */
    agentName?: pulumi.Input<string>;
    /**
     * The ARNs of the security group used to protect your data transfer task subnets.
     */
    securityGroupArns?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The ARNs of the subnets in which DataSync will create elastic network interfaces for each data transfer task.
     */
    subnetArns?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The ID of the VPC endpoint that the agent has access to.
     */
    vpcEndpointId?: pulumi.Input<string>;
}
