import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * The details of the repository creation template associated with the request.
 */
export declare function getRepositoryCreationTemplate(args: GetRepositoryCreationTemplateArgs, opts?: pulumi.InvokeOptions): Promise<GetRepositoryCreationTemplateResult>;
export interface GetRepositoryCreationTemplateArgs {
    /**
     * The repository namespace prefix associated with the repository creation template.
     */
    prefix: string;
}
export interface GetRepositoryCreationTemplateResult {
    /**
     * A list of enumerable Strings representing the repository creation scenarios that this template will apply towards. The two supported scenarios are PULL_THROUGH_CACHE and REPLICATION
     */
    readonly appliedFor?: enums.ecr.RepositoryCreationTemplateAppliedForItem[];
    /**
     * The date and time, in JavaScript date format, when the repository creation template was created.
     */
    readonly createdAt?: string;
    /**
     * The ARN of the role to be assumed by Amazon ECR. Amazon ECR will assume your supplied role when the customRoleArn is specified. When this field isn't specified, Amazon ECR will use the service-linked role for the repository creation template.
     */
    readonly customRoleArn?: string;
    /**
     * The description associated with the repository creation template.
     */
    readonly description?: string;
    /**
     * The encryption configuration associated with the repository creation template.
     */
    readonly encryptionConfiguration?: outputs.ecr.RepositoryCreationTemplateEncryptionConfiguration;
    /**
     * The tag mutability setting for the repository. If this parameter is omitted, the default setting of MUTABLE will be used which will allow image tags to be overwritten. If IMMUTABLE is specified, all image tags within the repository will be immutable which will prevent them from being overwritten.
     */
    readonly imageTagMutability?: enums.ecr.RepositoryCreationTemplateImageTagMutability;
    /**
     * The lifecycle policy to use for repositories created using the template.
     */
    readonly lifecyclePolicy?: string;
    /**
     * he repository policy to apply to repositories created using the template. A repository policy is a permissions policy associated with a repository to control access permissions.
     */
    readonly repositoryPolicy?: string;
    /**
     * The metadata to apply to the repository to help you categorize and organize. Each tag consists of a key and an optional value, both of which you define. Tag keys can have a maximum character length of 128 characters, and tag values can have a maximum length of 256 characters.
     */
    readonly resourceTags?: outputs.ecr.RepositoryCreationTemplateTag[];
    /**
     * The date and time, in JavaScript date format, when the repository creation template was last updated.
     */
    readonly updatedAt?: string;
}
/**
 * The details of the repository creation template associated with the request.
 */
export declare function getRepositoryCreationTemplateOutput(args: GetRepositoryCreationTemplateOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRepositoryCreationTemplateResult>;
export interface GetRepositoryCreationTemplateOutputArgs {
    /**
     * The repository namespace prefix associated with the repository creation template.
     */
    prefix: pulumi.Input<string>;
}
