import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * An outcome for rule evaluation.
 */
export declare class Outcome extends pulumi.CustomResource {
    /**
     * Get an existing Outcome resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Outcome;
    /**
     * Returns true if the given object is an instance of Outcome.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Outcome;
    /**
     * The outcome ARN.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The timestamp when the outcome was created.
     */
    readonly createdTime: pulumi.Output<string>;
    /**
     * The outcome description.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The timestamp when the outcome was last updated.
     */
    readonly lastUpdatedTime: pulumi.Output<string>;
    /**
     * The name of the outcome.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Tags associated with this outcome.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Outcome resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: OutcomeArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Outcome resource.
 */
export interface OutcomeArgs {
    /**
     * The outcome description.
     */
    description?: pulumi.Input<string>;
    /**
     * The name of the outcome.
     */
    name?: pulumi.Input<string>;
    /**
     * Tags associated with this outcome.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
