import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The AWS::GameLift::Alias resource creates an alias for an Amazon GameLift (GameLift) fleet destination.
 */
export declare function getAlias(args: GetAliasArgs, opts?: pulumi.InvokeOptions): Promise<GetAliasResult>;
export interface GetAliasArgs {
    /**
     * Unique alias ID
     */
    aliasId: string;
}
export interface GetAliasResult {
    /**
     * The Amazon Resource Name (ARN) that is assigned to a Amazon GameLift Alias resource and uniquely identifies it. ARNs are unique across all Regions. In a GameLift Alias ARN, the resource ID matches the AliasId value.
     */
    readonly aliasArn?: string;
    /**
     * Unique alias ID
     */
    readonly aliasId?: string;
    /**
     * A human-readable description of the alias.
     */
    readonly description?: string;
    /**
     * A descriptive label that is associated with an alias. Alias names do not need to be unique.
     */
    readonly name?: string;
    /**
     * A routing configuration that specifies where traffic is directed for this alias, such as to a fleet or to a message.
     */
    readonly routingStrategy?: outputs.gamelift.AliasRoutingStrategy;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * The AWS::GameLift::Alias resource creates an alias for an Amazon GameLift (GameLift) fleet destination.
 */
export declare function getAliasOutput(args: GetAliasOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAliasResult>;
export interface GetAliasOutputArgs {
    /**
     * Unique alias ID
     */
    aliasId: pulumi.Input<string>;
}
