import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Glue::Database
 */
export declare class Database extends pulumi.CustomResource {
    /**
     * Get an existing Database resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Database;
    /**
     * Returns true if the given object is an instance of Database.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Database;
    /**
     * The AWS account ID for the account in which to create the catalog object.
     */
    readonly catalogId: pulumi.Output<string>;
    /**
     * The metadata for the database.
     */
    readonly databaseInput: pulumi.Output<outputs.glue.DatabaseInput>;
    /**
     * The name of the database. For hive compatibility, this is folded to lowercase when it is store.
     */
    readonly databaseName: pulumi.Output<string | undefined>;
    /**
     * Create a Database resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DatabaseArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Database resource.
 */
export interface DatabaseArgs {
    /**
     * The AWS account ID for the account in which to create the catalog object.
     */
    catalogId: pulumi.Input<string>;
    /**
     * The metadata for the database.
     */
    databaseInput: pulumi.Input<inputs.glue.DatabaseInputArgs>;
    /**
     * The name of the database. For hive compatibility, this is folded to lowercase when it is store.
     */
    databaseName?: pulumi.Input<string>;
}
