import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type Definition for AWS:IdentityStore::GroupMembership
 */
export declare class GroupMembership extends pulumi.CustomResource {
    /**
     * Get an existing GroupMembership resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): GroupMembership;
    /**
     * Returns true if the given object is an instance of GroupMembership.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is GroupMembership;
    /**
     * The unique identifier for a group in the identity store.
     */
    readonly groupId: pulumi.Output<string>;
    /**
     * The globally unique identifier for the identity store.
     */
    readonly identityStoreId: pulumi.Output<string>;
    /**
     * An object containing the identifier of a group member.
     */
    readonly memberId: pulumi.Output<outputs.identitystore.GroupMembershipMemberId>;
    /**
     * The identifier for a GroupMembership in the identity store.
     */
    readonly membershipId: pulumi.Output<string>;
    /**
     * Create a GroupMembership resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: GroupMembershipArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a GroupMembership resource.
 */
export interface GroupMembershipArgs {
    /**
     * The unique identifier for a group in the identity store.
     */
    groupId: pulumi.Input<string>;
    /**
     * The globally unique identifier for the identity store.
     */
    identityStoreId: pulumi.Input<string>;
    /**
     * An object containing the identifier of a group member.
     */
    memberId: pulumi.Input<inputs.identitystore.GroupMembershipMemberIdArgs>;
}
