import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * A dimension can be used to limit the scope of a metric used in a security profile for AWS IoT Device Defender.
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const topicFilterForAuthMessagesDimension = new aws_native.iot.Dimension("topicFilterForAuthMessagesDimension", {
 *     name: "TopicFilterForAuthMessages",
 *     type: aws_native.iot.DimensionType.TopicFilter,
 *     stringValues: ["device/+/auth"],
 *     tags: [{
 *         key: "Application",
 *         value: "SmartHome",
 *     }],
 * });
 *
 * ```
 */
export declare class Dimension extends pulumi.CustomResource {
    /**
     * Get an existing Dimension resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Dimension;
    /**
     * Returns true if the given object is an instance of Dimension.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Dimension;
    /**
     * The ARN (Amazon resource name) of the created dimension.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * A unique identifier for the dimension.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * Specifies the value or list of values for the dimension.
     */
    readonly stringValues: pulumi.Output<string[]>;
    /**
     * Metadata that can be used to manage the dimension.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Specifies the type of the dimension.
     */
    readonly type: pulumi.Output<enums.iot.DimensionType>;
    /**
     * Create a Dimension resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DimensionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Dimension resource.
 */
export interface DimensionArgs {
    /**
     * A unique identifier for the dimension.
     */
    name?: pulumi.Input<string>;
    /**
     * Specifies the value or list of values for the dimension.
     */
    stringValues: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Metadata that can be used to manage the dimension.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * Specifies the type of the dimension.
     */
    type: pulumi.Input<enums.iot.DimensionType>;
}
