import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * An example resource schema demonstrating some basic constructs and validation rules.
 */
export declare function getSuiteDefinition(args: GetSuiteDefinitionArgs, opts?: pulumi.InvokeOptions): Promise<GetSuiteDefinitionResult>;
export interface GetSuiteDefinitionArgs {
    /**
     * The unique identifier for the suite definition.
     */
    suiteDefinitionId: string;
}
export interface GetSuiteDefinitionResult {
    /**
     * The Amazon Resource name for the suite definition.
     */
    readonly suiteDefinitionArn?: string;
    /**
     * The configuration of the Suite Definition. Listed below are the required elements of the `SuiteDefinitionConfiguration` .
     *
     * - ***devicePermissionRoleArn*** - The device permission arn.
     *
     * This is a required element.
     *
     * *Type:* String
     * - ***devices*** - The list of configured devices under test. For more information on devices under test, see [DeviceUnderTest](https://docs.aws.amazon.com/iot/latest/apireference/API_iotdeviceadvisor_DeviceUnderTest.html)
     *
     * Not a required element.
     *
     * *Type:* List of devices under test
     * - ***intendedForQualification*** - The tests intended for qualification in a suite.
     *
     * Not a required element.
     *
     * *Type:* Boolean
     * - ***rootGroup*** - The test suite root group. For more information on creating and using root groups see the [Device Advisor workflow](https://docs.aws.amazon.com/iot/latest/developerguide/device-advisor-workflow.html) .
     *
     * This is a required element.
     *
     * *Type:* String
     * - ***suiteDefinitionName*** - The Suite Definition Configuration name.
     *
     * This is a required element.
     *
     * *Type:* String
     */
    readonly suiteDefinitionConfiguration?: outputs.iotcoredeviceadvisor.SuiteDefinitionConfigurationProperties;
    /**
     * The unique identifier for the suite definition.
     */
    readonly suiteDefinitionId?: string;
    /**
     * The suite definition version of a test suite.
     */
    readonly suiteDefinitionVersion?: string;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * An example resource schema demonstrating some basic constructs and validation rules.
 */
export declare function getSuiteDefinitionOutput(args: GetSuiteDefinitionOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetSuiteDefinitionResult>;
export interface GetSuiteDefinitionOutputArgs {
    /**
     * The unique identifier for the suite definition.
     */
    suiteDefinitionId: pulumi.Input<string>;
}
