import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource schema for AWS::IoTSiteWise::AssetModel
 */
export declare class AssetModel extends pulumi.CustomResource {
    /**
     * Get an existing AssetModel resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): AssetModel;
    /**
     * Returns true if the given object is an instance of AssetModel.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AssetModel;
    /**
     * The ARN of the asset model, which has the following format.
     */
    readonly assetModelArn: pulumi.Output<string>;
    /**
     * The composite asset models that are part of this asset model. Composite asset models are asset models that contain specific properties.
     */
    readonly assetModelCompositeModels: pulumi.Output<outputs.iotsitewise.AssetModelCompositeModel[] | undefined>;
    /**
     * A description for the asset model.
     */
    readonly assetModelDescription: pulumi.Output<string | undefined>;
    /**
     * The external ID of the asset model.
     */
    readonly assetModelExternalId: pulumi.Output<string | undefined>;
    /**
     * The hierarchy definitions of the asset model. Each hierarchy specifies an asset model whose assets can be children of any other assets created from this asset model. You can specify up to 10 hierarchies per asset model.
     */
    readonly assetModelHierarchies: pulumi.Output<outputs.iotsitewise.AssetModelHierarchy[] | undefined>;
    /**
     * The ID of the asset model.
     */
    readonly assetModelId: pulumi.Output<string>;
    /**
     * A unique, friendly name for the asset model.
     */
    readonly assetModelName: pulumi.Output<string>;
    /**
     * The property definitions of the asset model. You can specify up to 200 properties per asset model.
     */
    readonly assetModelProperties: pulumi.Output<outputs.iotsitewise.AssetModelProperty[] | undefined>;
    /**
     * The type of the asset model (ASSET_MODEL OR COMPONENT_MODEL)
     */
    readonly assetModelType: pulumi.Output<string | undefined>;
    /**
     * A list of key-value pairs that contain metadata for the asset model.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a AssetModel resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: AssetModelArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a AssetModel resource.
 */
export interface AssetModelArgs {
    /**
     * The composite asset models that are part of this asset model. Composite asset models are asset models that contain specific properties.
     */
    assetModelCompositeModels?: pulumi.Input<pulumi.Input<inputs.iotsitewise.AssetModelCompositeModelArgs>[]>;
    /**
     * A description for the asset model.
     */
    assetModelDescription?: pulumi.Input<string>;
    /**
     * The external ID of the asset model.
     */
    assetModelExternalId?: pulumi.Input<string>;
    /**
     * The hierarchy definitions of the asset model. Each hierarchy specifies an asset model whose assets can be children of any other assets created from this asset model. You can specify up to 10 hierarchies per asset model.
     */
    assetModelHierarchies?: pulumi.Input<pulumi.Input<inputs.iotsitewise.AssetModelHierarchyArgs>[]>;
    /**
     * A unique, friendly name for the asset model.
     */
    assetModelName?: pulumi.Input<string>;
    /**
     * The property definitions of the asset model. You can specify up to 200 properties per asset model.
     */
    assetModelProperties?: pulumi.Input<pulumi.Input<inputs.iotsitewise.AssetModelPropertyArgs>[]>;
    /**
     * The type of the asset model (ASSET_MODEL OR COMPONENT_MODEL)
     */
    assetModelType?: pulumi.Input<string>;
    /**
     * A list of key-value pairs that contain metadata for the asset model.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
