import * as pulumi from "@pulumi/pulumi";
/**
 * Resource schema for AWS::IoTTwinMaker::Workspace
 */
export declare class Workspace extends pulumi.CustomResource {
    /**
     * Get an existing Workspace resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Workspace;
    /**
     * Returns true if the given object is an instance of Workspace.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Workspace;
    /**
     * The ARN of the workspace.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The date and time when the workspace was created.
     */
    readonly creationDateTime: pulumi.Output<string>;
    /**
     * The description of the workspace.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The ARN of the execution role associated with the workspace.
     */
    readonly role: pulumi.Output<string>;
    /**
     * The ARN of the S3 bucket where resources associated with the workspace are stored.
     */
    readonly s3Location: pulumi.Output<string>;
    /**
     * A map of key-value pairs to associate with a resource.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * The date and time of the current update.
     */
    readonly updateDateTime: pulumi.Output<string>;
    /**
     * The ID of the workspace.
     */
    readonly workspaceId: pulumi.Output<string>;
    /**
     * Create a Workspace resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: WorkspaceArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Workspace resource.
 */
export interface WorkspaceArgs {
    /**
     * The description of the workspace.
     */
    description?: pulumi.Input<string>;
    /**
     * The ARN of the execution role associated with the workspace.
     */
    role: pulumi.Input<string>;
    /**
     * The ARN of the S3 bucket where resources associated with the workspace are stored.
     */
    s3Location: pulumi.Input<string>;
    /**
     * A map of key-value pairs to associate with a resource.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The ID of the workspace.
     */
    workspaceId: pulumi.Input<string>;
}
