import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::IVS::PlaybackKeyPair
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const playbackKeyPair = new aws_native.ivs.PlaybackKeyPair("playbackKeyPair", {
 *     publicKeyMaterial: `-----BEGIN PUBLIC KEY-----
 * MHYwEAYHKoZIzj0CAQYFK4EEACIDYgAEwOR43ETwEoWif1i14aL8GtDMNkT/kBQm
 * h4sas9P//bjCU988rmQQXVBfftKT9xngg+W6hzOEpeUlCRlAtz6b6U79naYYRaSk
 * K/UhYGWkXlbJlc9zn13imYWgVGe/BMFp
 * -----END PUBLIC KEY-----
 * `,
 *     name: "MyPlaybackKeyPair",
 *     tags: [{
 *         key: "MyKey",
 *         value: "MyValue",
 *     }],
 * });
 * export const playbackKeyPairArn = playbackKeyPair.id;
 * export const playbackKeyPairFingerprint = playbackKeyPair.fingerprint;
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const playbackKeyPair = new aws_native.ivs.PlaybackKeyPair("playbackKeyPair", {
 *     publicKeyMaterial: `-----BEGIN PUBLIC KEY-----
 * MHYwEAYHKoZIzj0CAQYFK4EEACIDYgAEwOR43ETwEoWif1i14aL8GtDMNkT/kBQm
 * h4sas9P//bjCU988rmQQXVBfftKT9xngg+W6hzOEpeUlCRlAtz6b6U79naYYRaSk
 * K/UhYGWkXlbJlc9zn13imYWgVGe/BMFp
 * -----END PUBLIC KEY-----
 * `,
 *     name: "MyPlaybackKeyPair",
 *     tags: [{
 *         key: "MyKey",
 *         value: "MyValue",
 *     }],
 * });
 * export const playbackKeyPairArn = playbackKeyPair.id;
 * export const playbackKeyPairFingerprint = playbackKeyPair.fingerprint;
 *
 * ```
 */
export declare class PlaybackKeyPair extends pulumi.CustomResource {
    /**
     * Get an existing PlaybackKeyPair resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): PlaybackKeyPair;
    /**
     * Returns true if the given object is an instance of PlaybackKeyPair.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is PlaybackKeyPair;
    /**
     * Key-pair identifier.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Key-pair identifier.
     */
    readonly fingerprint: pulumi.Output<string>;
    /**
     * An arbitrary string (a nickname) assigned to a playback key pair that helps the customer identify that resource. The value does not need to be unique.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * The public portion of a customer-generated key pair. This field is required to create the AWS::IVS::PlaybackKeyPair resource.
     */
    readonly publicKeyMaterial: pulumi.Output<string | undefined>;
    /**
     * A list of key-value pairs that contain metadata for the asset model.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a PlaybackKeyPair resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: PlaybackKeyPairArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a PlaybackKeyPair resource.
 */
export interface PlaybackKeyPairArgs {
    /**
     * An arbitrary string (a nickname) assigned to a playback key pair that helps the customer identify that resource. The value does not need to be unique.
     */
    name?: pulumi.Input<string>;
    /**
     * The public portion of a customer-generated key pair. This field is required to create the AWS::IVS::PlaybackKeyPair resource.
     */
    publicKeyMaterial?: pulumi.Input<string>;
    /**
     * A list of key-value pairs that contain metadata for the asset model.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
