import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * A Kendra FAQ resource
 */
export declare class Faq extends pulumi.CustomResource {
    /**
     * Get an existing Faq resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Faq;
    /**
     * Returns true if the given object is an instance of Faq.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Faq;
    /**
     * `arn:aws:kendra:us-west-2:111122223333:index/335c3741-41df-46a6-b5d3-61f85b787884/faq/f61995a6-cd5c-4e99-9cfc-58816d8bfaa7`
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The identifier for the FAQ. For example:
     *
     * `f61995a6-cd5c-4e99-9cfc-58816d8bfaa7`
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * FAQ description
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * FAQ file format
     */
    readonly fileFormat: pulumi.Output<enums.kendra.FaqFileFormat | undefined>;
    /**
     * Index ID
     */
    readonly indexId: pulumi.Output<string>;
    /**
     * The code for a language. This shows a supported language for the FAQ document as part of the summary information for FAQs. English is supported by default. For more information on supported languages, including their codes, see [Adding documents in languages other than English](https://docs.aws.amazon.com/kendra/latest/dg/in-adding-languages.html) .
     */
    readonly languageCode: pulumi.Output<string | undefined>;
    /**
     * FAQ name
     */
    readonly name: pulumi.Output<string>;
    /**
     * FAQ role ARN
     */
    readonly roleArn: pulumi.Output<string>;
    /**
     * FAQ S3 path
     */
    readonly s3Path: pulumi.Output<outputs.kendra.FaqS3Path>;
    /**
     * Tags for labeling the FAQ
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Faq resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: FaqArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Faq resource.
 */
export interface FaqArgs {
    /**
     * FAQ description
     */
    description?: pulumi.Input<string>;
    /**
     * FAQ file format
     */
    fileFormat?: pulumi.Input<enums.kendra.FaqFileFormat>;
    /**
     * Index ID
     */
    indexId: pulumi.Input<string>;
    /**
     * The code for a language. This shows a supported language for the FAQ document as part of the summary information for FAQs. English is supported by default. For more information on supported languages, including their codes, see [Adding documents in languages other than English](https://docs.aws.amazon.com/kendra/latest/dg/in-adding-languages.html) .
     */
    languageCode?: pulumi.Input<string>;
    /**
     * FAQ name
     */
    name?: pulumi.Input<string>;
    /**
     * FAQ role ARN
     */
    roleArn: pulumi.Input<string>;
    /**
     * FAQ S3 path
     */
    s3Path: pulumi.Input<inputs.kendra.FaqS3PathArgs>;
    /**
     * Tags for labeling the FAQ
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
