import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * A Bot Alias enables you to change the version of a bot without updating applications that use the bot
 */
export declare function getBotAlias(args: GetBotAliasArgs, opts?: pulumi.InvokeOptions): Promise<GetBotAliasResult>;
export interface GetBotAliasArgs {
    /**
     * The unique identifier of the bot alias.
     */
    botAliasId: string;
    /**
     * The unique identifier of the bot.
     */
    botId: string;
}
export interface GetBotAliasResult {
    /**
     * The Amazon Resource Name (ARN) of the bot alias.
     */
    readonly arn?: string;
    /**
     * The unique identifier of the bot alias.
     */
    readonly botAliasId?: string;
    /**
     * Specifies settings that are unique to a locale. For example, you can use different Lambda function depending on the bot's locale.
     */
    readonly botAliasLocaleSettings?: outputs.lex.BotAliasLocaleSettingsItem[];
    /**
     * The name of the bot alias.
     */
    readonly botAliasName?: string;
    /**
     * The current status of the bot alias. When the status is Available the alias is ready for use with your bot.
     */
    readonly botAliasStatus?: enums.lex.BotAliasStatus;
    /**
     * The version of the bot that the bot alias references.
     */
    readonly botVersion?: string;
    /**
     * Specifies whether Amazon Lex logs text and audio for conversations with the bot. When you enable conversation logs, text logs store text input, transcripts of audio input, and associated metadata in Amazon CloudWatch logs. Audio logs store input in Amazon S3 .
     */
    readonly conversationLogSettings?: outputs.lex.BotAliasConversationLogSettings;
    /**
     * The description of the bot alias.
     */
    readonly description?: string;
    /**
     * Determines whether Amazon Lex will use Amazon Comprehend to detect the sentiment of user utterances.
     */
    readonly sentimentAnalysisSettings?: outputs.lex.SentimentAnalysisSettingsProperties;
}
/**
 * A Bot Alias enables you to change the version of a bot without updating applications that use the bot
 */
export declare function getBotAliasOutput(args: GetBotAliasOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetBotAliasResult>;
export interface GetBotAliasOutputArgs {
    /**
     * The unique identifier of the bot alias.
     */
    botAliasId: pulumi.Input<string>;
    /**
     * The unique identifier of the bot.
     */
    botId: pulumi.Input<string>;
}
