import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::MediaConnect::Bridge
 */
export declare function getBridge(args: GetBridgeArgs, opts?: pulumi.InvokeOptions): Promise<GetBridgeResult>;
export interface GetBridgeArgs {
    /**
     * The Amazon Resource Number (ARN) of the bridge.
     */
    bridgeArn: string;
}
export interface GetBridgeResult {
    /**
     * The Amazon Resource Number (ARN) of the bridge.
     */
    readonly bridgeArn?: string;
    /**
     * The current status of the bridge. Possible values are: ACTIVE or STANDBY.
     */
    readonly bridgeState?: enums.mediaconnect.BridgeStateEnum;
    /**
     * An egress bridge is a cloud-to-ground bridge. The content comes from an existing MediaConnect flow and is delivered to your premises.
     */
    readonly egressGatewayBridge?: outputs.mediaconnect.BridgeEgressGatewayBridge;
    /**
     * An ingress bridge is a ground-to-cloud bridge. The content originates at your premises and is delivered to the cloud.
     */
    readonly ingressGatewayBridge?: outputs.mediaconnect.BridgeIngressGatewayBridge;
    /**
     * The name of the bridge.
     */
    readonly name?: string;
    /**
     * The outputs on this bridge.
     */
    readonly outputs?: outputs.mediaconnect.BridgeOutput[];
    /**
     * The placement Amazon Resource Number (ARN) of the bridge.
     */
    readonly placementArn?: string;
    /**
     * The settings for source failover.
     */
    readonly sourceFailoverConfig?: outputs.mediaconnect.BridgeFailoverConfig;
    /**
     * The sources on this bridge.
     */
    readonly sources?: outputs.mediaconnect.BridgeSource[];
}
/**
 * Resource schema for AWS::MediaConnect::Bridge
 */
export declare function getBridgeOutput(args: GetBridgeOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetBridgeResult>;
export interface GetBridgeOutputArgs {
    /**
     * The Amazon Resource Number (ARN) of the bridge.
     */
    bridgeArn: pulumi.Input<string>;
}
