import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::MemoryDB::ACL
 */
export declare class Acl extends pulumi.CustomResource {
    /**
     * Get an existing Acl resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Acl;
    /**
     * Returns true if the given object is an instance of Acl.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Acl;
    /**
     * The name of the acl.
     */
    readonly aclName: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the acl.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Indicates acl status. Can be "creating", "active", "modifying", "deleting".
     */
    readonly status: pulumi.Output<string>;
    /**
     * An array of key-value pairs to apply to this cluster.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * List of users associated to this acl.
     */
    readonly userNames: pulumi.Output<string[] | undefined>;
    /**
     * Create a Acl resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: AclArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Acl resource.
 */
export interface AclArgs {
    /**
     * The name of the acl.
     */
    aclName?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this cluster.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * List of users associated to this acl.
     */
    userNames?: pulumi.Input<pulumi.Input<string>[]>;
}
