import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The AWS::NetworkManager::Device type describes a device.
 */
export declare function getDevice(args: GetDeviceArgs, opts?: pulumi.InvokeOptions): Promise<GetDeviceResult>;
export interface GetDeviceArgs {
    /**
     * The ID of the device.
     */
    deviceId: string;
    /**
     * The ID of the global network.
     */
    globalNetworkId: string;
}
export interface GetDeviceResult {
    /**
     * The Amazon Web Services location of the device, if applicable.
     */
    readonly awsLocation?: outputs.networkmanager.DeviceAwsLocation;
    /**
     * The date and time that the device was created.
     */
    readonly createdAt?: string;
    /**
     * The description of the device.
     */
    readonly description?: string;
    /**
     * The Amazon Resource Name (ARN) of the device.
     */
    readonly deviceArn?: string;
    /**
     * The ID of the device.
     */
    readonly deviceId?: string;
    /**
     * The site location.
     */
    readonly location?: outputs.networkmanager.DeviceLocation;
    /**
     * The device model
     */
    readonly model?: string;
    /**
     * The device serial number.
     */
    readonly serialNumber?: string;
    /**
     * The site ID.
     */
    readonly siteId?: string;
    /**
     * The state of the device.
     */
    readonly state?: string;
    /**
     * The tags for the device.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The device type.
     */
    readonly type?: string;
    /**
     * The device vendor.
     */
    readonly vendor?: string;
}
/**
 * The AWS::NetworkManager::Device type describes a device.
 */
export declare function getDeviceOutput(args: GetDeviceOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDeviceResult>;
export interface GetDeviceOutputArgs {
    /**
     * The ID of the device.
     */
    deviceId: pulumi.Input<string>;
    /**
     * The ID of the global network.
     */
    globalNetworkId: pulumi.Input<string>;
}
