import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The AWS::NetworkManager::GlobalNetwork type specifies a global network of the user's account
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const globalNetwork = new aws_native.networkmanager.GlobalNetwork("globalNetwork", {});
 * const site = new aws_native.networkmanager.Site("site", {
 *     globalNetworkId: globalNetwork.id,
 *     location: {
 *         address: "227 W Monroe St, Chicago, IL 60606",
 *         latitude: "41.8",
 *         longitude: "-87.6",
 *     },
 * });
 * const link = new aws_native.networkmanager.Link("link", {
 *     description: "Broadband link",
 *     globalNetworkId: globalNetwork.id,
 *     siteId: site.siteId,
 *     bandwidth: {
 *         downloadSpeed: 20,
 *         uploadSpeed: 20,
 *     },
 *     provider: "AnyCompany",
 *     type: "Broadband",
 *     tags: [{
 *         key: "Name",
 *         value: "broadband-link-1",
 *     }],
 * });
 * const device = new aws_native.networkmanager.Device("device", {
 *     description: "Chicago office device",
 *     globalNetworkId: globalNetwork.id,
 *     siteId: site.siteId,
 *     tags: [{
 *         key: "Network",
 *         value: "north-america",
 *     }],
 * });
 * const linkAssociation = new aws_native.networkmanager.LinkAssociation("linkAssociation", {
 *     globalNetworkId: globalNetwork.id,
 *     linkId: link.linkId,
 *     deviceId: device.deviceId,
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const globalNetwork = new aws_native.networkmanager.GlobalNetwork("globalNetwork", {});
 * const site = new aws_native.networkmanager.Site("site", {
 *     globalNetworkId: globalNetwork.id,
 *     location: {
 *         address: "227 W Monroe St, Chicago, IL 60606",
 *         latitude: "41.8",
 *         longitude: "-87.6",
 *     },
 * });
 * const link = new aws_native.networkmanager.Link("link", {
 *     description: "Broadband link",
 *     globalNetworkId: globalNetwork.id,
 *     siteId: site.siteId,
 *     bandwidth: {
 *         downloadSpeed: 20,
 *         uploadSpeed: 20,
 *     },
 *     provider: "AnyCompany",
 *     type: "Broadband",
 *     tags: [{
 *         key: "Name",
 *         value: "broadband-link-1",
 *     }],
 * });
 * const device = new aws_native.networkmanager.Device("device", {
 *     description: "Chicago office device",
 *     globalNetworkId: globalNetwork.id,
 *     siteId: site.siteId,
 *     tags: [{
 *         key: "Network",
 *         value: "north-america",
 *     }],
 * });
 * const linkAssociation = new aws_native.networkmanager.LinkAssociation("linkAssociation", {
 *     globalNetworkId: globalNetwork.id,
 *     linkId: link.linkId,
 *     deviceId: device.deviceId,
 * });
 *
 * ```
 */
export declare class GlobalNetwork extends pulumi.CustomResource {
    /**
     * Get an existing GlobalNetwork resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): GlobalNetwork;
    /**
     * Returns true if the given object is an instance of GlobalNetwork.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is GlobalNetwork;
    /**
     * The Amazon Resource Name (ARN) of the global network.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The ID of the global network.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The date and time that the global network was created.
     */
    readonly createdAt: pulumi.Output<string | undefined>;
    /**
     * The description of the global network.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The state of the global network.
     */
    readonly state: pulumi.Output<string | undefined>;
    /**
     * The tags for the global network.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a GlobalNetwork resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: GlobalNetworkArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a GlobalNetwork resource.
 */
export interface GlobalNetworkArgs {
    /**
     * The date and time that the global network was created.
     */
    createdAt?: pulumi.Input<string>;
    /**
     * The description of the global network.
     */
    description?: pulumi.Input<string>;
    /**
     * The state of the global network.
     */
    state?: pulumi.Input<string>;
    /**
     * The tags for the global network.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
