import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Schema describing various properties for AWS Proton Environment Account Connections resources.
 */
export declare class EnvironmentAccountConnection extends pulumi.CustomResource {
    /**
     * Get an existing EnvironmentAccountConnection resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): EnvironmentAccountConnection;
    /**
     * Returns true if the given object is an instance of EnvironmentAccountConnection.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is EnvironmentAccountConnection;
    /**
     * The Amazon Resource Name (ARN) of the environment account connection.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The ID of the environment account connection.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of an IAM service role in the environment account. AWS Proton uses this role to provision infrastructure resources using CodeBuild-based provisioning in the associated environment account.
     */
    readonly codebuildRoleArn: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the IAM service role that AWS Proton uses when provisioning directly defined components in the associated environment account. It determines the scope of infrastructure that a component can provision in the account.
     */
    readonly componentRoleArn: pulumi.Output<string | undefined>;
    /**
     * The environment account that's connected to the environment account connection.
     */
    readonly environmentAccountId: pulumi.Output<string | undefined>;
    /**
     * The name of the AWS Proton environment that's created in the associated management account.
     */
    readonly environmentName: pulumi.Output<string | undefined>;
    /**
     * The ID of the management account that accepts or rejects the environment account connection. You create an manage the AWS Proton environment in this account. If the management account accepts the environment account connection, AWS Proton can use the associated IAM role to provision environment infrastructure resources in the associated environment account.
     */
    readonly managementAccountId: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the IAM service role that's created in the environment account. AWS Proton uses this role to provision infrastructure resources in the associated environment account.
     */
    readonly roleArn: pulumi.Output<string | undefined>;
    /**
     * The status of the environment account connection.
     */
    readonly status: pulumi.Output<enums.proton.EnvironmentAccountConnectionStatus>;
    /**
     * <p>An optional list of metadata items that you can associate with the Proton environment account connection. A tag is a key-value pair.</p>
     *          <p>For more information, see <a href="https://docs.aws.amazon.com/proton/latest/userguide/resources.html">Proton resources and tagging</a> in the
     *         <i>Proton User Guide</i>.</p>
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a EnvironmentAccountConnection resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: EnvironmentAccountConnectionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a EnvironmentAccountConnection resource.
 */
export interface EnvironmentAccountConnectionArgs {
    /**
     * The Amazon Resource Name (ARN) of an IAM service role in the environment account. AWS Proton uses this role to provision infrastructure resources using CodeBuild-based provisioning in the associated environment account.
     */
    codebuildRoleArn?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the IAM service role that AWS Proton uses when provisioning directly defined components in the associated environment account. It determines the scope of infrastructure that a component can provision in the account.
     */
    componentRoleArn?: pulumi.Input<string>;
    /**
     * The environment account that's connected to the environment account connection.
     */
    environmentAccountId?: pulumi.Input<string>;
    /**
     * The name of the AWS Proton environment that's created in the associated management account.
     */
    environmentName?: pulumi.Input<string>;
    /**
     * The ID of the management account that accepts or rejects the environment account connection. You create an manage the AWS Proton environment in this account. If the management account accepts the environment account connection, AWS Proton can use the associated IAM role to provision environment infrastructure resources in the associated environment account.
     */
    managementAccountId?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the IAM service role that's created in the environment account. AWS Proton uses this role to provision infrastructure resources in the associated environment account.
     */
    roleArn?: pulumi.Input<string>;
    /**
     * <p>An optional list of metadata items that you can associate with the Proton environment account connection. A tag is a key-value pair.</p>
     *          <p>For more information, see <a href="https://docs.aws.amazon.com/proton/latest/userguide/resources.html">Proton resources and tagging</a> in the
     *         <i>Proton User Guide</i>.</p>
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
