import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Specifies an Amazon Redshift subnet group.
 */
export declare class ClusterSubnetGroup extends pulumi.CustomResource {
    /**
     * Get an existing ClusterSubnetGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ClusterSubnetGroup;
    /**
     * Returns true if the given object is an instance of ClusterSubnetGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ClusterSubnetGroup;
    /**
     * This name must be unique for all subnet groups that are created by your AWS account. If costumer do not provide it, cloudformation will generate it. Must not be "Default".
     */
    readonly clusterSubnetGroupName: pulumi.Output<string>;
    /**
     * The description of the parameter group.
     */
    readonly description: pulumi.Output<string>;
    /**
     * The list of VPC subnet IDs
     */
    readonly subnetIds: pulumi.Output<string[]>;
    /**
     * The list of tags for the cluster parameter group.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a ClusterSubnetGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ClusterSubnetGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ClusterSubnetGroup resource.
 */
export interface ClusterSubnetGroupArgs {
    /**
     * The description of the parameter group.
     */
    description: pulumi.Input<string>;
    /**
     * The list of VPC subnet IDs
     */
    subnetIds: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The list of tags for the cluster parameter group.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
