import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::RolesAnywhere::CRL Resource Type
 */
export declare class Crl extends pulumi.CustomResource {
    /**
     * Get an existing Crl resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Crl;
    /**
     * Returns true if the given object is an instance of Crl.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Crl;
    /**
     * The x509 v3 specified certificate revocation list (CRL).
     */
    readonly crlData: pulumi.Output<string>;
    /**
     * The unique primary identifier of the Crl
     */
    readonly crlId: pulumi.Output<string>;
    /**
     * Specifies whether the certificate revocation list (CRL) is enabled.
     */
    readonly enabled: pulumi.Output<boolean | undefined>;
    /**
     * The name of the certificate revocation list (CRL).
     */
    readonly name: pulumi.Output<string>;
    /**
     * A list of tags to attach to the certificate revocation list (CRL).
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The ARN of the TrustAnchor the certificate revocation list (CRL) will provide revocation for.
     */
    readonly trustAnchorArn: pulumi.Output<string | undefined>;
    /**
     * Create a Crl resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CrlArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Crl resource.
 */
export interface CrlArgs {
    /**
     * The x509 v3 specified certificate revocation list (CRL).
     */
    crlData: pulumi.Input<string>;
    /**
     * Specifies whether the certificate revocation list (CRL) is enabled.
     */
    enabled?: pulumi.Input<boolean>;
    /**
     * The name of the certificate revocation list (CRL).
     */
    name?: pulumi.Input<string>;
    /**
     * A list of tags to attach to the certificate revocation list (CRL).
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The ARN of the TrustAnchor the certificate revocation list (CRL) will provide revocation for.
     */
    trustAnchorArn?: pulumi.Input<string>;
}
