import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * AWS Route53 Recovery Readiness Recovery Group Schema and API specifications.
 */
export declare class RecoveryGroup extends pulumi.CustomResource {
    /**
     * Get an existing RecoveryGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): RecoveryGroup;
    /**
     * Returns true if the given object is an instance of RecoveryGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is RecoveryGroup;
    /**
     * A list of the cell Amazon Resource Names (ARNs) in the recovery group.
     */
    readonly cells: pulumi.Output<string[] | undefined>;
    /**
     * A collection of tags associated with a resource.
     */
    readonly recoveryGroupArn: pulumi.Output<string>;
    /**
     * The name of the recovery group to create.
     */
    readonly recoveryGroupName: pulumi.Output<string | undefined>;
    /**
     * A collection of tags associated with a resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a RecoveryGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: RecoveryGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a RecoveryGroup resource.
 */
export interface RecoveryGroupArgs {
    /**
     * A list of the cell Amazon Resource Names (ARNs) in the recovery group.
     */
    cells?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The name of the recovery group to create.
     */
    recoveryGroupName?: pulumi.Input<string>;
    /**
     * A collection of tags associated with a resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
