import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The AWS::S3::StorageLensGroup resource is an Amazon S3 resource type that you can use to create Storage Lens Group.
 */
export declare class StorageLensGroup extends pulumi.CustomResource {
    /**
     * Get an existing StorageLensGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): StorageLensGroup;
    /**
     * Returns true if the given object is an instance of StorageLensGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is StorageLensGroup;
    /**
     * This property contains the criteria for the Storage Lens group data that is displayed
     */
    readonly filter: pulumi.Output<outputs.s3.StorageLensGroupFilter>;
    /**
     * This property contains the Storage Lens group name.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The ARN for the Amazon S3 Storage Lens Group.
     */
    readonly storageLensGroupArn: pulumi.Output<string>;
    /**
     * A set of tags (key-value pairs) for this Amazon S3 Storage Lens Group.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a StorageLensGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: StorageLensGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a StorageLensGroup resource.
 */
export interface StorageLensGroupArgs {
    /**
     * This property contains the criteria for the Storage Lens group data that is displayed
     */
    filter: pulumi.Input<inputs.s3.StorageLensGroupFilterArgs>;
    /**
     * This property contains the Storage Lens group name.
     */
    name?: pulumi.Input<string>;
    /**
     * A set of tags (key-value pairs) for this Amazon S3 Storage Lens Group.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
