import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::SageMaker::AppImageConfig
 */
export declare class AppImageConfig extends pulumi.CustomResource {
    /**
     * Get an existing AppImageConfig resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): AppImageConfig;
    /**
     * Returns true if the given object is an instance of AppImageConfig.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AppImageConfig;
    /**
     * The Amazon Resource Name (ARN) of the AppImageConfig.
     */
    readonly appImageConfigArn: pulumi.Output<string>;
    /**
     * The Name of the AppImageConfig.
     */
    readonly appImageConfigName: pulumi.Output<string>;
    /**
     * The CodeEditorAppImageConfig.
     */
    readonly codeEditorAppImageConfig: pulumi.Output<outputs.sagemaker.AppImageConfigCodeEditorAppImageConfig | undefined>;
    /**
     * The JupyterLabAppImageConfig.
     */
    readonly jupyterLabAppImageConfig: pulumi.Output<outputs.sagemaker.AppImageConfigJupyterLabAppImageConfig | undefined>;
    /**
     * The KernelGatewayImageConfig.
     */
    readonly kernelGatewayImageConfig: pulumi.Output<outputs.sagemaker.AppImageConfigKernelGatewayImageConfig | undefined>;
    /**
     * A list of tags to apply to the AppImageConfig.
     */
    readonly tags: pulumi.Output<outputs.CreateOnlyTag[] | undefined>;
    /**
     * Create a AppImageConfig resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: AppImageConfigArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a AppImageConfig resource.
 */
export interface AppImageConfigArgs {
    /**
     * The Name of the AppImageConfig.
     */
    appImageConfigName?: pulumi.Input<string>;
    /**
     * The CodeEditorAppImageConfig.
     */
    codeEditorAppImageConfig?: pulumi.Input<inputs.sagemaker.AppImageConfigCodeEditorAppImageConfigArgs>;
    /**
     * The JupyterLabAppImageConfig.
     */
    jupyterLabAppImageConfig?: pulumi.Input<inputs.sagemaker.AppImageConfigJupyterLabAppImageConfigArgs>;
    /**
     * The KernelGatewayImageConfig.
     */
    kernelGatewayImageConfig?: pulumi.Input<inputs.sagemaker.AppImageConfigKernelGatewayImageConfigArgs>;
    /**
     * A list of tags to apply to the AppImageConfig.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.CreateOnlyTagArgs>[]>;
}
