import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::SageMaker::Project
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const sampleProject = new aws_native.sagemaker.Project("sampleProject", {
 *     projectName: "project1",
 *     projectDescription: "Project Description",
 *     serviceCatalogProvisioningDetails: {
 *         productId: "prod-53ibyqbj2cgmo",
 *         provisioningArtifactId: "pa-sm4pjfuzictpe",
 *     },
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const sampleProject = new aws_native.sagemaker.Project("sampleProject", {
 *     projectName: "SampleProject",
 *     projectDescription: "Project Description",
 *     serviceCatalogProvisioningDetails: {
 *         productId: "prod-53ibyqbj2cgmo",
 *         provisioningArtifactId: "pa-sm4pjfuzictpe",
 *     },
 * });
 *
 * ```
 */
export declare class Project extends pulumi.CustomResource {
    /**
     * Get an existing Project resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Project;
    /**
     * Returns true if the given object is an instance of Project.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Project;
    /**
     * The time at which the project was created.
     */
    readonly creationTime: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the project.
     */
    readonly projectArn: pulumi.Output<string>;
    /**
     * The description of the project.
     */
    readonly projectDescription: pulumi.Output<string | undefined>;
    /**
     * The ID of the project. This ID is prepended to all entities associated with this project.
     */
    readonly projectId: pulumi.Output<string>;
    /**
     * The name of the project.
     */
    readonly projectName: pulumi.Output<string>;
    /**
     * The status of a project.
     */
    readonly projectStatus: pulumi.Output<enums.sagemaker.ProjectStatus>;
    /**
     * Provisioned ServiceCatalog  Details
     */
    readonly serviceCatalogProvisionedProductDetails: pulumi.Output<outputs.sagemaker.ServiceCatalogProvisionedProductDetailsProperties | undefined>;
    /**
     * Input ServiceCatalog Provisioning Details
     */
    readonly serviceCatalogProvisioningDetails: pulumi.Output<outputs.sagemaker.ServiceCatalogProvisioningDetailsProperties>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.CreateOnlyTag[] | undefined>;
    /**
     * Create a Project resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ProjectArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Project resource.
 */
export interface ProjectArgs {
    /**
     * The description of the project.
     */
    projectDescription?: pulumi.Input<string>;
    /**
     * The name of the project.
     */
    projectName?: pulumi.Input<string>;
    /**
     * Provisioned ServiceCatalog  Details
     */
    serviceCatalogProvisionedProductDetails?: pulumi.Input<inputs.sagemaker.ServiceCatalogProvisionedProductDetailsPropertiesArgs>;
    /**
     * Input ServiceCatalog Provisioning Details
     */
    serviceCatalogProvisioningDetails: pulumi.Input<inputs.sagemaker.ServiceCatalogProvisioningDetailsPropertiesArgs>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.CreateOnlyTagArgs>[]>;
}
