import * as pulumi from "@pulumi/pulumi";
/**
 * Resource Schema for AWS::ServiceCatalogAppRegistry::Application
 */
export declare class Application extends pulumi.CustomResource {
    /**
     * Get an existing Application resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Application;
    /**
     * Returns true if the given object is an instance of Application.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Application;
    /**
     * The name of the application.
     */
    readonly applicationName: pulumi.Output<string>;
    /**
     * The key of the AWS application tag, which is awsApplication. Applications created before 11/13/2023 or applications without the AWS application tag resource group return no value.
     */
    readonly applicationTagKey: pulumi.Output<string>;
    /**
     * The value of the AWS application tag, which is the identifier of an associated resource. Applications created before 11/13/2023 or applications without the AWS application tag resource group return no value.
     */
    readonly applicationTagValue: pulumi.Output<string>;
    /**
     * The Amazon resource name (ARN) that specifies the application across services.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The identifier of the application.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The description of the application.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The name of the application.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Key-value pairs you can use to associate with the application.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a Application resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ApplicationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Application resource.
 */
export interface ApplicationArgs {
    /**
     * The description of the application.
     */
    description?: pulumi.Input<string>;
    /**
     * The name of the application.
     */
    name?: pulumi.Input<string>;
    /**
     * Key-value pairs you can use to associate with the application.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
