import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::SES::VdmAttributes
 */
export declare class VdmAttributes extends pulumi.CustomResource {
    /**
     * Get an existing VdmAttributes resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): VdmAttributes;
    /**
     * Returns true if the given object is an instance of VdmAttributes.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is VdmAttributes;
    /**
     * Specifies additional settings for your VDM configuration as applicable to the Dashboard.
     */
    readonly dashboardAttributes: pulumi.Output<outputs.ses.VdmAttributesDashboardAttributes | undefined>;
    /**
     * Specifies additional settings for your VDM configuration as applicable to the Guardian.
     */
    readonly guardianAttributes: pulumi.Output<outputs.ses.VdmAttributesGuardianAttributes | undefined>;
    /**
     * Unique identifier for this resource
     */
    readonly vdmAttributesResourceId: pulumi.Output<string>;
    /**
     * Create a VdmAttributes resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: VdmAttributesArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a VdmAttributes resource.
 */
export interface VdmAttributesArgs {
    /**
     * Specifies additional settings for your VDM configuration as applicable to the Dashboard.
     */
    dashboardAttributes?: pulumi.Input<inputs.ses.VdmAttributesDashboardAttributesArgs>;
    /**
     * Specifies additional settings for your VDM configuration as applicable to the Guardian.
     */
    guardianAttributes?: pulumi.Input<inputs.ses.VdmAttributesGuardianAttributesArgs>;
}
