import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::SSMContacts::Contact
 */
export declare class Contact extends pulumi.CustomResource {
    /**
     * Get an existing Contact resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Contact;
    /**
     * Returns true if the given object is an instance of Contact.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Contact;
    /**
     * Alias of the contact. String value with 20 to 256 characters. Only alphabetical, numeric characters, dash, or underscore allowed.
     */
    readonly alias: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the contact.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Name of the contact. String value with 3 to 256 characters. Only alphabetical, space, numeric characters, dash, or underscore allowed.
     */
    readonly displayName: pulumi.Output<string>;
    /**
     * The stages that an escalation plan or engagement plan engages contacts and contact methods in.
     */
    readonly plan: pulumi.Output<outputs.ssmcontacts.ContactStage[] | undefined>;
    /**
     * Contact type, which specify type of contact. Currently supported values: "PERSONAL", "SHARED", "OTHER".
     */
    readonly type: pulumi.Output<enums.ssmcontacts.ContactType>;
    /**
     * Create a Contact resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ContactArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Contact resource.
 */
export interface ContactArgs {
    /**
     * Alias of the contact. String value with 20 to 256 characters. Only alphabetical, numeric characters, dash, or underscore allowed.
     */
    alias: pulumi.Input<string>;
    /**
     * Name of the contact. String value with 3 to 256 characters. Only alphabetical, space, numeric characters, dash, or underscore allowed.
     */
    displayName: pulumi.Input<string>;
    /**
     * The stages that an escalation plan or engagement plan engages contacts and contact methods in.
     */
    plan?: pulumi.Input<pulumi.Input<inputs.ssmcontacts.ContactStageArgs>[]>;
    /**
     * Contact type, which specify type of contact. Currently supported values: "PERSONAL", "SHARED", "OTHER".
     */
    type: pulumi.Input<enums.ssmcontacts.ContactType>;
}
