import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * Resource Type definition for SSO application access grant to a user or group.
 */
export declare class ApplicationAssignment extends pulumi.CustomResource {
    /**
     * Get an existing ApplicationAssignment resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ApplicationAssignment;
    /**
     * Returns true if the given object is an instance of ApplicationAssignment.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ApplicationAssignment;
    /**
     * The ARN of the application.
     */
    readonly applicationArn: pulumi.Output<string>;
    /**
     * An identifier for an object in IAM Identity Center, such as a user or group
     */
    readonly principalId: pulumi.Output<string>;
    /**
     * The entity type for which the assignment will be created.
     */
    readonly principalType: pulumi.Output<enums.sso.ApplicationAssignmentPrincipalType>;
    /**
     * Create a ApplicationAssignment resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ApplicationAssignmentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ApplicationAssignment resource.
 */
export interface ApplicationAssignmentArgs {
    /**
     * The ARN of the application.
     */
    applicationArn: pulumi.Input<string>;
    /**
     * An identifier for an object in IAM Identity Center, such as a user or group
     */
    principalId: pulumi.Input<string>;
    /**
     * The entity type for which the assignment will be created.
     */
    principalType: pulumi.Input<enums.sso.ApplicationAssignmentPrincipalType>;
}
