import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Associates a service with a service network.
 */
export declare class ServiceNetworkServiceAssociation extends pulumi.CustomResource {
    /**
     * Get an existing ServiceNetworkServiceAssociation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ServiceNetworkServiceAssociation;
    /**
     * Returns true if the given object is an instance of ServiceNetworkServiceAssociation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ServiceNetworkServiceAssociation;
    /**
     * The Amazon Resource Name (ARN) of the association between the service network and the service.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The ID of the of the association between the service network and the service.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The date and time that the association was created, specified in ISO-8601 format.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The DNS information of the service.
     */
    readonly dnsEntry: pulumi.Output<outputs.vpclattice.ServiceNetworkServiceAssociationDnsEntry | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the service.
     */
    readonly serviceArn: pulumi.Output<string>;
    /**
     * The ID of the service.
     */
    readonly serviceId: pulumi.Output<string>;
    /**
     * The ID or ARN of the service.
     */
    readonly serviceIdentifier: pulumi.Output<string | undefined>;
    /**
     * The name of the service.
     */
    readonly serviceName: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the service network
     */
    readonly serviceNetworkArn: pulumi.Output<string>;
    /**
     * The ID of the service network.
     */
    readonly serviceNetworkId: pulumi.Output<string>;
    /**
     * The ID or ARN of the service network. You must use an ARN if the resources are in different accounts.
     */
    readonly serviceNetworkIdentifier: pulumi.Output<string | undefined>;
    /**
     * The name of the service network.
     */
    readonly serviceNetworkName: pulumi.Output<string>;
    /**
     * The status of the association between the service network and the service.
     */
    readonly status: pulumi.Output<enums.vpclattice.ServiceNetworkServiceAssociationStatus>;
    /**
     * The tags for the association.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a ServiceNetworkServiceAssociation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ServiceNetworkServiceAssociationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ServiceNetworkServiceAssociation resource.
 */
export interface ServiceNetworkServiceAssociationArgs {
    /**
     * The DNS information of the service.
     */
    dnsEntry?: pulumi.Input<inputs.vpclattice.ServiceNetworkServiceAssociationDnsEntryArgs>;
    /**
     * The ID or ARN of the service.
     */
    serviceIdentifier?: pulumi.Input<string>;
    /**
     * The ID or ARN of the service network. You must use an ARN if the resources are in different accounts.
     */
    serviceNetworkIdentifier?: pulumi.Input<string>;
    /**
     * The tags for the association.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
