import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::Wisdom::AIPrompt Resource Type
 */
export declare class AiPrompt extends pulumi.CustomResource {
    /**
     * Get an existing AiPrompt resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): AiPrompt;
    /**
     * Returns true if the given object is an instance of AiPrompt.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AiPrompt;
    /**
     * The Amazon Resource Name (ARN) of the AI Prompt.
     */
    readonly aiPromptArn: pulumi.Output<string>;
    /**
     * The identifier of the Amazon Q in Connect AI prompt.
     */
    readonly aiPromptId: pulumi.Output<string>;
    /**
     * The API format used for this AI Prompt.
     */
    readonly apiFormat: pulumi.Output<enums.wisdom.AiPromptAiPromptApiFormat>;
    /**
     * The Amazon Resource Name (ARN) of the Amazon Q in Connect assistant.
     */
    readonly assistantArn: pulumi.Output<string>;
    /**
     * The identifier of the Amazon Q in Connect assistant. Can be either the ID or the ARN. URLs cannot contain the ARN.
     */
    readonly assistantId: pulumi.Output<string | undefined>;
    /**
     * The description of the AI Prompt.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The identifier of the model used for this AI Prompt. The following model Ids are supported:
     *
     * - `anthropic.claude-3-haiku--v1:0`
     * - `apac.amazon.nova-lite-v1:0`
     * - `apac.amazon.nova-micro-v1:0`
     * - `apac.amazon.nova-pro-v1:0`
     * - `apac.anthropic.claude-3-5-sonnet--v2:0`
     * - `apac.anthropic.claude-3-haiku-20240307-v1:0`
     * - `eu.amazon.nova-lite-v1:0`
     * - `eu.amazon.nova-micro-v1:0`
     * - `eu.amazon.nova-pro-v1:0`
     * - `eu.anthropic.claude-3-7-sonnet-20250219-v1:0`
     * - `eu.anthropic.claude-3-haiku-20240307-v1:0`
     * - `us.amazon.nova-lite-v1:0`
     * - `us.amazon.nova-micro-v1:0`
     * - `us.amazon.nova-pro-v1:0`
     * - `us.anthropic.claude-3-5-haiku-20241022-v1:0`
     * - `us.anthropic.claude-3-7-sonnet-20250219-v1:0`
     * - `us.anthropic.claude-3-haiku-20240307-v1:0`
     */
    readonly modelId: pulumi.Output<string>;
    readonly modifiedTimeSeconds: pulumi.Output<number>;
    /**
     * The name of the AI Prompt
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * The tags used to organize, track, or control access for this resource.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * The configuration of the prompt template for this AI Prompt.
     */
    readonly templateConfiguration: pulumi.Output<outputs.wisdom.AiPromptAiPromptTemplateConfiguration>;
    /**
     * The type of the prompt template for this AI Prompt.
     */
    readonly templateType: pulumi.Output<enums.wisdom.AiPromptAiPromptTemplateType>;
    /**
     * The type of this AI Prompt.
     */
    readonly type: pulumi.Output<enums.wisdom.AiPromptAiPromptType>;
    /**
     * Create a AiPrompt resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AiPromptArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a AiPrompt resource.
 */
export interface AiPromptArgs {
    /**
     * The API format used for this AI Prompt.
     */
    apiFormat: pulumi.Input<enums.wisdom.AiPromptAiPromptApiFormat>;
    /**
     * The identifier of the Amazon Q in Connect assistant. Can be either the ID or the ARN. URLs cannot contain the ARN.
     */
    assistantId?: pulumi.Input<string>;
    /**
     * The description of the AI Prompt.
     */
    description?: pulumi.Input<string>;
    /**
     * The identifier of the model used for this AI Prompt. The following model Ids are supported:
     *
     * - `anthropic.claude-3-haiku--v1:0`
     * - `apac.amazon.nova-lite-v1:0`
     * - `apac.amazon.nova-micro-v1:0`
     * - `apac.amazon.nova-pro-v1:0`
     * - `apac.anthropic.claude-3-5-sonnet--v2:0`
     * - `apac.anthropic.claude-3-haiku-20240307-v1:0`
     * - `eu.amazon.nova-lite-v1:0`
     * - `eu.amazon.nova-micro-v1:0`
     * - `eu.amazon.nova-pro-v1:0`
     * - `eu.anthropic.claude-3-7-sonnet-20250219-v1:0`
     * - `eu.anthropic.claude-3-haiku-20240307-v1:0`
     * - `us.amazon.nova-lite-v1:0`
     * - `us.amazon.nova-micro-v1:0`
     * - `us.amazon.nova-pro-v1:0`
     * - `us.anthropic.claude-3-5-haiku-20241022-v1:0`
     * - `us.anthropic.claude-3-7-sonnet-20250219-v1:0`
     * - `us.anthropic.claude-3-haiku-20240307-v1:0`
     */
    modelId: pulumi.Input<string>;
    /**
     * The name of the AI Prompt
     */
    name?: pulumi.Input<string>;
    /**
     * The tags used to organize, track, or control access for this resource.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The configuration of the prompt template for this AI Prompt.
     */
    templateConfiguration: pulumi.Input<inputs.wisdom.AiPromptAiPromptTemplateConfigurationArgs>;
    /**
     * The type of the prompt template for this AI Prompt.
     */
    templateType: pulumi.Input<enums.wisdom.AiPromptAiPromptTemplateType>;
    /**
     * The type of this AI Prompt.
     */
    type: pulumi.Input<enums.wisdom.AiPromptAiPromptType>;
}
