import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::WorkSpacesWeb::IpAccessSettings Resource Type
 */
export declare class IpAccessSettings extends pulumi.CustomResource {
    /**
     * Get an existing IpAccessSettings resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): IpAccessSettings;
    /**
     * Returns true if the given object is an instance of IpAccessSettings.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is IpAccessSettings;
    /**
     * Additional encryption context of the IP access settings.
     */
    readonly additionalEncryptionContext: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * A list of web portal ARNs that this IP access settings resource is associated with.
     */
    readonly associatedPortalArns: pulumi.Output<string[]>;
    /**
     * The creation date timestamp of the IP access settings.
     */
    readonly creationDate: pulumi.Output<string>;
    /**
     * The custom managed key of the IP access settings.
     *
     * *Pattern* : `^arn:[\w+=\/,.@-]+:kms:[a-zA-Z0-9\-]*:[a-zA-Z0-9]{1,12}:key\/[a-zA-Z0-9-]+$`
     */
    readonly customerManagedKey: pulumi.Output<string | undefined>;
    /**
     * The description of the IP access settings.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The display name of the IP access settings.
     */
    readonly displayName: pulumi.Output<string | undefined>;
    /**
     * The ARN of the IP access settings resource.
     */
    readonly ipAccessSettingsArn: pulumi.Output<string>;
    /**
     * The IP rules of the IP access settings.
     */
    readonly ipRules: pulumi.Output<outputs.workspacesweb.IpAccessSettingsIpRule[]>;
    /**
     * The tags to add to the IP access settings resource. A tag is a key-value pair.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a IpAccessSettings resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IpAccessSettingsArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a IpAccessSettings resource.
 */
export interface IpAccessSettingsArgs {
    /**
     * Additional encryption context of the IP access settings.
     */
    additionalEncryptionContext?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The custom managed key of the IP access settings.
     *
     * *Pattern* : `^arn:[\w+=\/,.@-]+:kms:[a-zA-Z0-9\-]*:[a-zA-Z0-9]{1,12}:key\/[a-zA-Z0-9-]+$`
     */
    customerManagedKey?: pulumi.Input<string>;
    /**
     * The description of the IP access settings.
     */
    description?: pulumi.Input<string>;
    /**
     * The display name of the IP access settings.
     */
    displayName?: pulumi.Input<string>;
    /**
     * The IP rules of the IP access settings.
     */
    ipRules: pulumi.Input<pulumi.Input<inputs.workspacesweb.IpAccessSettingsIpRuleArgs>[]>;
    /**
     * The tags to add to the IP access settings resource. A tag is a key-value pair.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
